# This package allows conditional builds
#
# Default values are --with-mysql
#
# Read: If neither macro exists, then add the default definition.
%{!?_with_mysql: %{!?_with_Pg: %{!?_with_Oracle: %{!?_with_SQLite: %define _with_mysql --with-mysql}}}}

# mod_perl is disabled in this build
#%{!?_with_modperl1: %{!?_with_modperl2: %define _with_modperl2 --with-modperl2}}

# Webserver setup
%define webusr apache
%define webgrp apache
%define rtname rt
%define fullrtname request-tracker
%define svn svn7331
# Database setup
%define dbhost localhost
%{?_with_mysql:    %define dba    root}
%{?_with_Pg:       %define dba    postgres}
%{?_with_Oracle:   %define dba    system}
%{?_with_SQLite:   %define dba    root}

%define dbname %rtname
%define dbuser %rtname

%define wwwroot %_var/www/html

Summary: Request Tracker (RT) is an enterprise-grade issue tracking system
Name: %fullrtname
Version: 3.6.3
Release: alt3.%svn
Group: Networking/WWW
License: GPL
Url: http://www.bestpractical.com/rt/
Source: http://download.bestpractical.com/pub/rt/devel/%rtname-%version.tar.gz
BuildArch: noarch

# Obsolete old names
Obsoletes: rt

# patch for support new perl
Patch0: %rtname-alt-perl-5.8.4-support.patch
# ALT Linux FS layout support
Patch1: %rtname-alt-layout.patch
# Disable chown/chgrp in Makefile
Patch2: %rtname-alt-makefile.patch
# Support koi8-r and cp1251 encodings in emails
Patch3: %rtname-alt-encodings.patch

Source1: %rtname-apache-vhost.conf
Source2: %rtname-rt-remind
Source3: %rtname-initialdata-ru
Source4: %rtname-ru.po
Source5: %rtname-rt-count
Source6: %rtname-rt-escalate

BuildRequires: autoconf perl
#AutoReqProv: noperl
AutoReq: no

%define siteconfig %_sysconfdir/%rtname/RT_SiteConfig.pm

# this build uses fastcgi
%define apacheconfig %_sysconfdir/httpd/conf/vhosts.d/%rtname.conf.example

# Common packages
Requires: apache-common
Requires: postfix
Requires: /usr/bin/perl
Requires: perl >= 5.8.0
Requires: mod_fastcgi
# Perl modules
Requires: perl(Params/Validate.pm)
Requires: perl(Cache/Cache.pm)
Requires: perl(Exception/Class.pm)
Requires: perl(HTML/Mason.pm)
Requires: perl(MLDBM.pm)
Requires: perl(FreezeThaw.pm)
Requires: perl(Errno.pm)
Requires: perl(Digest/MD5.pm)
Requires: perl(CGI/Cookie.pm)
Requires: perl(Storable.pm)
Requires: perl(Apache/Session.pm)
Requires: perl(XML/RSS.pm)
Requires: perl(HTML/TreeBuilder.pm)
Requires: perl(HTML/FormatText.pm)
Requires: perl(Getopt/Long.pm)
Requires: perl(LWP/UserAgent.pm)
Requires: perl(Digest/base.pm)
Requires: perl(DBI.pm)
Requires: perl(Test/Inline.pm)
Requires: perl(Class/ReturnValue.pm)
Requires: perl(DBIx/SearchBuilder.pm) >= 1.48
Requires: perl(Text/Template.pm)
Requires: perl(File/Spec.pm)
Requires: perl(HTML/Entities.pm)
Requires: perl(HTML/Scrubber.pm)
Requires: perl(Net/Domain.pm)
Requires: perl(Log/Dispatch.pm)
Requires: perl(Locale/Maketext.pm)
Requires: perl(Locale/Maketext/Lexicon.pm)
Requires: perl(Locale/Maketext/Fuzzy.pm)
Requires: perl(MIME/Entity.pm)
Requires: perl(Mail/Mailer.pm)
Requires: perl(Net/SMTP.pm)
Requires: perl(Text/Wrapper.pm)
Requires: perl(Time/ParseDate.pm)
Requires: perl(File/Temp.pm)
Requires: perl(Term/ReadKey.pm)
Requires: perl(Text/Autoformat.pm)
Requires: perl(Text/Quoted.pm)
Requires: perl(Tree/Simple.pm)
Requires: perl(Scalar/Util.pm)
Requires: perl(Module/Versions/Report.pm)
Requires: perl(YAML.pm)
Requires: perl(Regexp/Common.pm)
Requires: perl(Time/HiRes.pm)
Requires: perl(HTML/Form.pm)
Requires: perl(HTML/TokeParser.pm)
Requires: perl(WWW/Mechanize.pm)
Requires: perl(FCGI.pm)
Requires: perl(CPAN.pm)
Requires: perl(Calendar/Simple.pm)
Requires: perl(UNIVERSAL/require.pm)

%{?_with_mysql:Requires: perl(DBD/mysql.pm)}
%{?_with_Pg:Requires: perl(DBD/Pg.pm)}
%{?_with_Oracle:Requires: perl(DBD/Oracle.pm)}
%{?_with_Sybase:Requires: perl(DBD/SQLite.pm)}

%description
Request Tracker (RT) is an enterprise-grade issue tracking system. It allows
organizations to keep track of their to-do lists, who is working
on which tasks, what's already been done, and when tasks were
completed. It is available under the terms of version 2 of the GNU
General Public License (GPL), so it doesn't cost anything to set
up and use.

Built options:
     %{?_with_mysql}%{?_with_Pg}%{?_with_Informix}
     --with-db-host=%dbhost
     --with-db-dba=%dba --with-db-rt-user=%dbuser
     --with-db-database=%dbname
     --with-web-user=%webusr --with-web-group=%webgrp


%package ru
Summary: Full russian support for the %name
Group: Networking/WWW
Requires: %name = %version

%description ru
Full russian support for %name

%package postgresql
Summary: PostgreSQL support for the %name
Group: Networking/WWW
Requires: %name = %version
Requires: perl(DBD/Pg.pm)

%description postgresql
PostgreSQL support for the %name

%package oracle
Summary: Oracle support for the %name
Group: Networking/WWW
Requires: %name = %version
Requires: perl(DBD/Oracle.pm)

%description oracle
Oracle support for the %name

%package sqlite
Summary: SQLite support for the %name
Group: Networking/WWW
Requires: %name = %version
Requires: perl(DBD/SQLite.pm)

%description sqlite
SQLite support for the %name


%prep

bdcount=0
%{?_with_mysql:bdcount=$[ bdcount + 1]}
%{?_with_Pg:bdcount=$[ bdcount + 1]}
%{?_with_Oracle:bdcount=$[ bdcount + 1]}
%{?_with_SQLite:bdcount=$[ bdcount + 1]}
if [ $bdcount != 1 ] ; then
  echo 'only one of --with mysql, --with Pg, --with Oracle, --with-SQLite must be specified' >&2
  exit -1
fi

# now the normal stuff
%setup -q -n %rtname-%version

%patch0 -p1
#%%patch1 -p1
cat <<EOF >>config.layout
<Layout ALT>
  prefix:              %_prefix
  exec_prefix:         %_prefix
  bindir:              %_libdir/%rtname/bin
  sbindir:             %_libdir/%rtname/sbin
  sysconfdir:          %_sysconfdir/%rtname
  datadir:             %_datadir
  libdir:              %_libdir/%rtname/lib
  mandir:              %_mandir
  vardir:              %_var
  htmldir:             %_var/www/html/%rtname
  manualdir:           %_defaultdocdir/%rtname-%version
  localstatedir:       %_libdir/%rtname
  logfiledir:          %_logdir/%rtname
  masonstatedir:       %_localstatedir/%rtname/cache/mason_data
  sessionstatedir:     %_localstatedir/%rtname/cache/session_data
  customdir:           %_libdir/%rtname/local
  customdir2:          %_var/www/html/%rtname/local
  custometcdir:        %_libdir/%rtname/local/etc
  customhtmldir:       %_var/www/html/%rtname/local/html
  customlexdir:        %_libdir/%rtname/local/po
  customlibdir:        %_libdir/%rtname/local/lib
</Layout>
EOF
%patch2 -p1
%patch3 -p1

%build
%__subst "s/\[3.6.HEAD\]/\[%version.%svn\]/g" ./configure.ac
autoconf ./configure.ac >./configure
chmod a+x ./configure
#            %{?_with_modperl1}%{?_with_modperl2} \
./configure --prefix=%_prefix --enable-layout=ALT \
            %{?_with_mysql}%{?_with_Pg}%{?_with_Oracle}%{?_with_SQLite} \
            --with-db-host=%dbhost \
            --with-db-dba=%dba --with-db-rt-user=%dbuser \
            --with-db-database=%dbname \
            --with-web-user=%webusr --with-web-group=%webgrp \
			--with-apachectl=%_sbindir/apachectl

%install
make DESTDIR=%buildroot install

%__mkdir_p %buildroot%_localstatedir/%rtname/cache/mason_data/{cache,etc,obj}
%__mkdir_p %buildroot%_localstatedir/%rtname/cache/session_data

%__mkdir_p %buildroot%wwwroot/%rtname/local/html
%__mkdir_p %buildroot%wwwroot/%rtname/RTx
%__mkdir_p %buildroot%_libdir/%rtname/bin
%__mkdir_p %buildroot%_libdir/%rtname/lib/RTx
%__mkdir_p %buildroot%_libdir/%rtname/local/{etc,po,lib}

# apache config
%__mkdir_p %buildroot%_sysconfdir/httpd/conf/vhosts.d
%__cp %SOURCE1 %buildroot%apacheconfig

# rt-remind,rt-count and rt-escalate scripts
%__cp %SOURCE2 %buildroot%_libdir/%rtname/bin/rt-remind
%__cp %SOURCE5 %buildroot%_libdir/%rtname/bin/rt-count
%__cp %SOURCE6 %buildroot%_libdir/%rtname/bin/rt-escalate

# new russian files
%__cp %SOURCE3 %buildroot%_libdir/%rtname/local/etc/initialdata
%__cp %SOURCE4 %buildroot%_libdir/%rtname/local/po/ru.po

# fix permissions
find %buildroot%_libdir/%rtname/ -type d -print0 | xargs -r0 chmod 2755 --
find %buildroot%_libdir/%rtname/ -type f -print0 | xargs -r0 chmod 0644 --
find %buildroot%_libdir/%rtname/ -name '*.pm' -type f -print0 | xargs -r0 chmod 0755 --
find %buildroot%_libdir/%rtname/bin/ -type f -print0 |xargs -r0 chmod 0755 --
find %buildroot%_libdir/%rtname/sbin/ -type f -print0 |xargs -r0 chmod 0755 --
find %buildroot%wwwroot/%rtname -type d -print0 |xargs -r0 chmod 2755 --
find %buildroot%wwwroot/%rtname -type f -print0 |xargs -r0 chmod 0644 --
find %buildroot%_libdir/%rtname/local -type d -print0 |xargs -r0 chmod 2755 --
#this will be /usr/share/docs
find docs -type f -print0 |xargs -r0 chmod 0644 --

mkdir -p %buildroot%_var/log/%rtname
touch %buildroot%_var/log/%rtname/%rtname.log

#%pre
#/usr/sbin/groupadd -r %rtname


%post
#check for compliance
perl /usr/lib/rt/sbin/rt-test-dependencies %{?_with_mysql}%{?_with_Pg}%{?_with_Informix} --with-fastcgi

cat <<EOF
	Congratulations. RT has been installed.

You must now configure RT by editing %siteconfig and %apacheconfig.

(You will definitely need to set RT's database password before continuing. Not doing
so could be very dangerous)

After that, you need to initialize RT's database by running:

%_libdir/%rtname/sbin/rt-setup-database --action init \ 
     --dba %dba --prompt-for-dba-password

If something goes wrong you can always drop everything, by executing:

%_libdir/%rtname/sbin/rt-setup-database --action drop \ 
     --dba %dba --prompt-for-dba-password

Look into these scripts and put them in the crontab:

%_libdir/%rtname/bin/rt-remind
%_libdir/%rtname/bin/rt-escalate
%_libdir/%rtname/bin/rt-count

Put these lines in the /etc/aliases and read the docs:

# RT aliases
support: "|%_libdir/%rtname/bin/rt-mailgate --queue 'General' --action correspond --url https://rt.example.com/"
support-comments: "|%_libdir/%rtname/bin/rt-mailgate --queue 'General' --action comment --url https://rt.example.com/"
#
    Go to the http://wiki.bestpractical.com/ for contribs and docs

EOF

%post postgresql

echo ""
echo "You must change database type in the config."
echo ""
echo "After that, you need to initialize RT's database by running"
echo ""
echo "%_libdir/%rtname/sbin/rt-setup-database --action init \ "
echo "     --dba postgres --prompt-for-dba-password"
echo ""
echo "If something goes wrong you can always drop everything, by executing"
echo ""
echo "%_libdir/%rtname/sbin/rt-setup-database --action drop \ "
echo "     --dba postgres --prompt-for-dba-password"
echo ""

%post oracle

echo ""
echo "You must change database type in the config."
echo ""
echo "After that, you need to initialize RT's database by running"
echo ""
echo "%_libdir/%rtname/sbin/rt-setup-database --action init \ "
echo "     --dba system --prompt-for-dba-password"
echo ""
echo "If something goes wrong you can always drop everything, by executing"
echo ""
echo "%_libdir/%rtname/sbin/rt-setup-database --action drop \ "
echo "     --dba system --prompt-for-dba-password"
echo ""

%post sqlite

echo ""
echo "You must change database type in the config."
echo ""
echo "After that, you need to initialize RT's database by running"
echo ""
echo "%_libdir/%rtname/sbin/rt-setup-database --action init \ "
echo "     --dba root --prompt-for-dba-password"
echo ""
echo "If something goes wrong you can always drop everything, by executing"
echo ""
echo "%_libdir/%rtname/sbin/rt-setup-database --action drop \ "
echo "     --dba root --prompt-for-dba-password"
echo ""

%files
%doc etc/upgrade README README.Oracle COPYING docs UPGRADING ChangeLog
%attr(-,root,%webgrp) %_libdir/%rtname
%attr(2775,root,%webgrp) %dir %_var/log/%rtname
%attr(0664,root,%webgrp) %_var/log/%rtname/%rtname.log
%attr(-,root,%webgrp) %_localstatedir/%rtname
%attr(2775,root,%webgrp) %dir %_localstatedir/%rtname/cache
%attr(2775,root,%webgrp) %dir %_localstatedir/%rtname/cache/mason_data
%attr(2775,root,%webgrp) %dir %_localstatedir/%rtname/cache/mason_data/cache
%attr(2775,root,%webgrp) %dir %_localstatedir/%rtname/cache/mason_data/etc
%attr(2775,root,%webgrp) %dir %_localstatedir/%rtname/cache/mason_data/obj
%attr(2775,root,%webgrp) %dir %_localstatedir/%rtname/cache/session_data
%attr(-,%webusr,%webgrp) %wwwroot/%rtname
%attr(0750,root,%webgrp) %dir /%_sysconfdir/%rtname
%attr(0640,root,%webgrp) %config(noreplace) /%_sysconfdir/%rtname/*
%attr(0640,root,%webgrp) %config(noreplace) /%_libdir/%rtname/local/etc/*
%attr(0640,root,root) %config(noreplace) %apacheconfig

%files ru
%attr(-,root,%webgrp) %_libdir/%rtname/local/etc/initialdata
%attr(-,root,%webgrp) %_libdir/%rtname/local/po/ru.po

%files postgresql
%files oracle
%files sqlite

%changelog
* Tue Mar 27 2007 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.3-alt3.svn7331
- Requires SearchBuilder >=1.48

* Sun Mar 25 2007 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.3-alt2.svn7331
- Latest SVN updates
- Spec cleanups
- rt.conf is in the vhosts.d now
- New dependency on postfix
- Updated rt-remind script
- New rt-escalate and rt-count scripts

* Mon Feb 05 2007 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.3-alt1.svn6946
- Bugfixes from SVN
- Added virtual packages which provide PostgreSQL, Oracle and SQLite support

* Tue Dec 26 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.3-alt1.svn6691
- Bugfix release

* Tue Dec 19 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.2-alt1
- 3.6.2 release
- Updated russian translation
- Fixed perl-UNIVERSAL-require dependency

* Tue Oct 03 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.1-alt1.svn6144
- Latest SVN updates
- Updated russian translation
- Spec cleanups
- rt-remind script fixes
- Patch #1 (layout) moved to the spec for buildtime macroses
- New perl modules dependencies (UNIVERSAL/require.pm)

* Wed Jun 21 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.6.0-alt2.svn5413
- New major release with many of new features (+ updates from SVN)
- Added upgrade directory
- New requirement (Calendar/Simple.pm)
- Requires SearchBuilder >=1.39
- Updated russian translation and russian initialdata

* Fri May 05 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.5-alt1.svn5167
- Latest SVN updates
- libexecdir changed to libdir

* Wed Feb 08 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.5-alt1.svn4503
- Latest SVN updates
- Added perl-CPAN dependency, updated SearchBuilder version dependency

* Sat Jan 21 2006 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.5-alt1.svn4431
- 3.4.5 and latest SVN updates
- lib/RTx and html/RTx created now by main package

* Wed Sep 28 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.4-alt3.svn3881
- Moved /usr/lib/rt/RT to /usr/lib/rt/lib
- Removed *.in files 

* Sun Sep 25 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.4-alt2.svn3881
- Fixed configuration files permissions
- Patch autoconf script for version
- Fresh translations
- Fixed layout patch

* Sat Sep 24 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.4-alt1.svn3881
- Latest svn updates
- Package renamed to request-tracket
- First build with deps

* Sat Aug 27 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.4rc3-alt1.svn3726
- Latest svn updates

* Thu May 26 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.2-alt1.svn2969
- Latest svn updates
- Updated translation

* Tue May 24 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.2-alt2.svn2931
- Fixed wrong fs layout (cache moved back to /var/lib/rt)
- Typo in previous build wasn't typo ;) Fixed
- Fixed wrong permissions on critical config files (anybody can see database
  password)
- Added missed requires: perl(FCGI.pm) and mod_fastcgi  

* Mon May 23 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.2-alt1.svn2931
- Version 3.4.2 + latest updates from SVN
- Fixed typo in vhosts file rt.conf
- Updated translation
- /var/lib/rt/local moved to /usr/lib/rt/local
- Removed .svn
- Corrected options for rt-test-dependencies (now --with-fastcgi)

* Mon Apr 04 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.1-alt3.svn2586
- Latest updates from SVN

* Mon Mar 14 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.1-alt3.svn2464
- Latest updates from SVN

* Wed Mar 02 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.1-alt2
- New heavy updated Russian translation from me

* Tue Mar 01 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.1-alt1
- latest 3.4.1 from svn
- rt.conf cleanups
- ru.po fixed (removed RTFM messages) + additional translation
- updated makefile patch

* Wed Feb 02 2005 Andrew Kornilov <hiddenman@altlinux.ru> 3.4.0-alt1
- New upstream release
- New Apache's rt.conf file with examples of external auth
- New messages from upstream ru.po file merged to my own ;-)
- New patch for support koi8-r and cp1251 encodings in email
- Added fresh Changelog

* Fri Dec 10 2004 Andrew Kornilov <hiddenman@altlinux.ru> 3.3.14-alt1
- New version
- Spec fixes (added noreplace for configs)

* Thu Nov 11 2004 Andrew Kornilov <hiddenman@altlinux.ru> 3.3.9-alt2
- Some fixes. Added russian package (my initial data and my reworked ru.po)

* Thu Nov 11 2004 Andrew Kornilov <hiddenman@altlinux.ru> 3.3.9-alt1
- First build for Sisyphus. Inital spec based on spec by Paulo Matos
  <paulo.matos@fct.unl.pt> (but fully reworked)
- Many bugs in spec, wrong FSH and other. But it works ;-)

